pub struct ClientName(/* private fields */);Trait Implementations
Sourceimpl AsRef<Pattern<ClientNamePatternKind>> for ClientName
impl AsRef<Pattern<ClientNamePatternKind>> for ClientName
Sourcefn as_ref(&self) -> &ClientNamePattern
fn as_ref(&self) -> &ClientNamePattern
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for ClientName
impl Clone for ClientName
Sourcefn clone(&self) -> ClientName
fn clone(&self) -> ClientName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientName
impl Debug for ClientName
Sourceimpl Display for ClientName
impl Display for ClientName
impl Eq for ClientName
Sourceimpl From<ClientName> for ClientNamePattern
impl From<ClientName> for ClientNamePattern
Sourcefn from(value: ClientName) -> Self
fn from(value: ClientName) -> Self
Converts to this type from the input type.
Sourceimpl From<Pattern<ClientNamePatternKind>> for ClientName
impl From<Pattern<ClientNamePatternKind>> for ClientName
Sourcefn from(value: ClientNamePattern) -> Self
fn from(value: ClientNamePattern) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ClientName
impl PartialEq for ClientName
Sourcefn eq(&self, other: &ClientName) -> bool
fn eq(&self, other: &ClientName) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClientName