pub struct ClientNamePatternKind(/* private fields */);Trait Implementations
Sourceimpl AsRef<NormalPatternKind> for ClientNamePatternKind
impl AsRef<NormalPatternKind> for ClientNamePatternKind
Sourcefn as_ref(&self) -> &NormalPatternKind
fn as_ref(&self) -> &NormalPatternKind
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for ClientNamePatternKind
impl Clone for ClientNamePatternKind
Sourcefn clone(&self) -> ClientNamePatternKind
fn clone(&self) -> ClientNamePatternKind
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ClientNamePatternKind
Sourceimpl Debug for ClientNamePatternKind
impl Debug for ClientNamePatternKind
Sourceimpl<'de> Deserialize<'de> for ClientNamePatternKind
impl<'de> Deserialize<'de> for ClientNamePatternKind
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ClientNamePatternKind
Sourceimpl From<ClientNamePatternKind> for NormalPatternKind
impl From<ClientNamePatternKind> for NormalPatternKind
Sourcefn from(value: ClientNamePatternKind) -> Self
fn from(value: ClientNamePatternKind) -> Self
Converts to this type from the input type.
Sourceimpl From<NormalPatternKind> for ClientNamePatternKind
impl From<NormalPatternKind> for ClientNamePatternKind
Sourcefn from(value: NormalPatternKind) -> Self
fn from(value: NormalPatternKind) -> Self
Converts to this type from the input type.
Sourceimpl Ord for ClientNamePatternKind
impl Ord for ClientNamePatternKind
Sourcefn cmp(&self, other: &ClientNamePatternKind) -> Ordering
fn cmp(&self, other: &ClientNamePatternKind) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientNamePatternKind
impl PartialEq for ClientNamePatternKind
Sourcefn eq(&self, other: &ClientNamePatternKind) -> bool
fn eq(&self, other: &ClientNamePatternKind) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClientNamePatternKind
impl PartialOrd for ClientNamePatternKind
Sourceimpl Serialize for ClientNamePatternKind
impl Serialize for ClientNamePatternKind
impl StructuralPartialEq for ClientNamePatternKind