pub struct DomainPatternKind(/* private fields */);Trait Implementations
Sourceimpl AsRef<NormalPatternKind> for DomainPatternKind
impl AsRef<NormalPatternKind> for DomainPatternKind
Sourcefn as_ref(&self) -> &NormalPatternKind
fn as_ref(&self) -> &NormalPatternKind
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for DomainPatternKind
impl Clone for DomainPatternKind
Sourcefn clone(&self) -> DomainPatternKind
fn clone(&self) -> DomainPatternKind
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DomainPatternKind
Sourceimpl Debug for DomainPatternKind
impl Debug for DomainPatternKind
Sourceimpl<'de> Deserialize<'de> for DomainPatternKind
impl<'de> Deserialize<'de> for DomainPatternKind
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DomainPatternKind
Sourceimpl From<DomainPatternKind> for NormalPatternKind
impl From<DomainPatternKind> for NormalPatternKind
Sourcefn from(value: DomainPatternKind) -> Self
fn from(value: DomainPatternKind) -> Self
Converts to this type from the input type.
Sourceimpl From<NormalPatternKind> for DomainPatternKind
impl From<NormalPatternKind> for DomainPatternKind
Sourcefn from(value: NormalPatternKind) -> Self
fn from(value: NormalPatternKind) -> Self
Converts to this type from the input type.
Sourceimpl Ord for DomainPatternKind
impl Ord for DomainPatternKind
Sourcefn cmp(&self, other: &DomainPatternKind) -> Ordering
fn cmp(&self, other: &DomainPatternKind) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DomainPatternKind
impl PartialEq for DomainPatternKind
Sourcefn eq(&self, other: &DomainPatternKind) -> bool
fn eq(&self, other: &DomainPatternKind) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DomainPatternKind
impl PartialOrd for DomainPatternKind
Sourceimpl Serialize for DomainPatternKind
impl Serialize for DomainPatternKind
impl StructuralPartialEq for DomainPatternKind